

use "$data/data/ready_hh.dta",clear

egen vid=group(c_code s_code p_code lc1_code)
label var vid "Village identifier"
bys vid: gen villhh=_N

global default "c(0) h(2) vce(nncluster vid 17)"
global small "c(0) h(1.5) vce(nncluster vid 17)"
global large "c(0) h(3) vce(nncluster vid 17)"
global control "hhheadage hhheadlit member distance hhr_gender imonth" 

gen baldata=1
foreach j of varlist $control {
	replace baldata=0 if `j'==.
	}

cap log close
log using "jdehhresults", replace	

/*==========================================================================                                                                        
			
			This file produces all household-level results,
			except for Table 2, panel B

===========================================================================*/

*******************************************************************************
*	 TABLE 1 SUMMARY STATISTICS (FULL SAMPLE)
*******************************************************************************

sum hhheadage hhheadlit member health_vil hhmalaria netown size

*******************************************************************************
*	 TABLE 2A PRE_INTERVENTION DISCONTINUITY USING BRAC DATA
*******************************************************************************

rdrobust hhheadage mdistance,$default
rdrobust hhheadlit mdistance,$default
rdrobust member mdistance,$default


unique vid if abs(mdistance)<2 & hhheadage!=. //# of villages
unique vid if abs(mdistance)<2 & hhheadlit!=.  //# of villages
unique vid if abs(mdistance)<2 & member!=. //# of villages
sum hhheadage if mdistance>0 & mdistance<2 & hhheadage!=.  //control mean
sum hhheadlit if mdistance>0 & mdistance<2 & hhheadlit!=.
sum member if mdistance>0 & mdistance<2 & member!=.


*******************************************************************************
*	 TABLE 3 PROGRAM EFFECT ON PROPORTION OF HOUSEHOLD MEMBERS WITH MALARIA
*******************************************************************************

* Without covariates
rdrobust hhmalaria mdistance,$default
rdrobust hhmalaria mdistance,$small
rdrobust hhmalaria mdistance,$large

sum hhmalaria if abs(mdistance)<2 //# of obs
sum hhmalaria if abs(mdistance)<1.5
sum hhmalaria if abs(mdistance)<3

sum hhmalaria if mdistance>0 & mdistance<2 //control mean
sum hhmalaria if mdistance>0 & mdistance<1.5
sum hhmalaria if mdistance>0 & mdistance<3

unique vid if abs(mdistance)<2 //# of villages
unique vid if abs(mdistance)<1.5
unique vid if abs(mdistance)<3

* With covariates
rdrobust hhmalaria mdistance, covs($control) $default
rdrobust hhmalaria mdistance, covs($control) $small
rdrobust hhmalaria mdistance, covs($control) $large

sum hhmalaria if abs(mdistance)<2 & baldata==1 
sum hhmalaria if abs(mdistance)<1.5 & baldata==1 
sum hhmalaria if abs(mdistance)<3 & baldata==1 

sum hhmalaria if mdistance>0 & mdistance<2 & baldata==1 
sum hhmalaria if mdistance>0 & mdistance<1.5 & baldata==1 
sum hhmalaria if mdistance>0 & mdistance<3 & baldata==1 


*******************************************************************************
*	 TABLE 5 EFFECTS ON INCOME AND BEDNET OWNERSHIP PER CAPITA
*******************************************************************************

* Income 
rdrobust lag_income_pc mdistance,$default
sum lag_income_pc if abs(mdistance)<2 
sum lag_income_pc if mdistance>0 & mdistance<2

rdrobust lag_income_pc mdistance, covs($control) $default
sum lag_income_pc if abs(mdistance)<2 & baldata==1 
sum lag_income_pc if mdistance>0 & mdistance<2 & baldata==1 

* Bednet ownership per capita
rdrobust netown mdistance, $default
sum netown if abs(mdistance)<2
sum netown if mdistance>0 & mdistance<2

rdrobust netown mdistance, covs($control) $default
sum netown if abs(mdistance)<2 & baldata==1 
sum netown if mdistance>0 & mdistance<2 & baldata==1 

*******************************************************************************
*	 TABLE 8 EFFECTS ON MALARIA & BEDNETS BY PRE-TREATMENT INCOME
*******************************************************************************

* Proportion of household members with malaria
rdrobust hhmalaria mdistance if poor==1, $default
sum hhmalaria if abs(mdistance)<=2 & poor==1
sum hhmalaria if mdistance>0 & mdistance<2 & poor==1

rdrobust hhmalaria mdistance if poor==0, $default
sum hhmalaria if abs(mdistance)<=2 & poor==0
sum hhmalaria if mdistance>0 & mdistance<2 & poor==0


* Bednet owned per member
rdrobust netown mdistance if poor==1, $default
sum netown if abs(mdistance)<=2 & poor==1 & netown!=.
sum netown if mdistance>0 & mdistance<2 & poor==1 & netown!=.

rdrobust netown mdistance if poor==0, $default
sum netown if abs(mdistance)<=2 & poor==0 & netown!=.
sum netown if mdistance>0 & mdistance<2 & poor==0 & netown!=.

*******************************************************************************
*	 TABLE 10 OTHER RELATED OUTCOMES
*******************************************************************************

* Every household member owns at least one pair of shoes
rdrobust shoe mdistance, $default
sum shoe if abs(mdistance)<2
sum shoe if mdistance>0 & mdistance<2

*******************************************************************************
*	 TABLE A1 PROGRAM ACTIVITY IN LAST 6 MONTHS
*******************************************************************************

rdrobust ag_vil mdistance, $default
rdrobust ag_vil mdistance, $small
rdrobust ag_vil mdistance, $large
sum ag_vil if abs(mdistance)<2
sum ag_vil if abs(mdistance)<1.5
sum ag_vil if abs(mdistance)<3
sum ag_vil if mdistance>0 & mdistance<2
sum ag_vil if mdistance>0 & mdistance<1.5
sum ag_vil if mdistance>0 & mdistance<3

rdrobust ag_vil mdistance, covs($control) $default
rdrobust ag_vil mdistance, covs($control) $small
rdrobust ag_vil mdistance, covs($control) $large
sum ag_vil if abs(mdistance)<2 &  baldata==1 
sum ag_vil if abs(mdistance)<1.5 & baldata==1 
sum ag_vil if abs(mdistance)<3 & baldata==1 
sum ag_vil if mdistance>0 & mdistance<2 &  baldata==1 
sum ag_vil if mdistance>0 & mdistance<1.5 &  baldata==1 
sum ag_vil if mdistance>0 & mdistance<3 &  baldata==1 


*******************************************************************************
*	 TABLE A2 EFFECTS ON MALARIA: PARAMETRIC ESTIMATES
*******************************************************************************

gen cutoff=(mdistance<=0)
gen x=mdistance
gen x2=x^2
gen xint=x*cutoff
gen x2int=x2*cutoff

reg hhmalaria cutoff x xint x2 x2int,cluster(vid) 
reg hhmalaria cutoff x xint x2 x2int $control ,cluster(vid)

sum hhmalaria if mdistance>0
sum hhmalaria if mdistance>0 & baldata==1

*******************************************************************************
*	 OTHER RESULTS REPORTED IN THE TEXT
*******************************************************************************

* Household distance to health facility
rdrobust hhdisthealth mdistance, $default

* BRAC health program coverage
rdrobust health_vil mdistance, $default

* Fraction of HH will access to health program
bysort vid: egen health_total=total(health)
bysort vid: gen health_frac=health_total/_N
rdrobust health_frac mdistance,$default 

* Program impact on malaria, controling for health program coverage 
rdrobust hhmalaria mdistance, covs($control health_vil) $default

* Drop overlapping districts in the Central region with a mass LLIN distribution campaign
gen central=1 if c_code==1 | c_code==6 | c_code==13 | c_code==17 |  c_code==22 | c_code==24 | c_code==27
rdrobust hhmalaria mdistance if central!=1, $default

* Alternative malaria measure: at least one member of the household reports being infected by malaria
rdrobust hhmalaria2 mdistance, $default 

* At least one member of the household was pregnant at the time of the survey
rdrobust hhpregnancy mdistance, $default 

* Estimated effect on proportion of members with malaria, excluding HH reported a death
rdrobust hhmalaria mdistance if death!=1, $default

* Proportion of household consumption expenditure spent on tobacco and alcohol
rdrobust maleshare mdistance, $default

* Household turn to neighbors for health advice
rdrobust networkh mdistance, $default 

* Interaction effects between health program & agriculture program
gen inter_health_vil=cutoff*health_vil
gen inter_literacy=cutoff*hhheadlit
reg hhmalaria cutoff inter_health_vil health_vil x xint x2 x2int,cluster(vid) 

* wage employment
sum wage_emp if abs(mdistance)<2
rdrobust wage_emp mdistance, $default

* Check for sample attrition
gen treat=(mdistance<0)
gen rate_attrition=(25-villhh)/25


preserve
collapse (mean) rate_attrition mdistance treat, by (vid)
sum rate_attrition
* attrition result: analysis sample
ttest rate_attrition if abs(mdistance)<2, by(treat) 
restore

* McCrary test
cd "$data/McCrary"


DCdensity mdistance if mdistance<4, breakpoint(0) generate(Xj Yj r0 fhat se_fhat) b(0.6) h(2) 
drop Xj Yj r0 fhat se_fhat
cd ..

*******************************************************************************
*	 FIGURE 1 HOUSEHOLD DENSITY
*******************************************************************************

egen denbins = cut(mdistance), at(-6(0.3)6)
replace denbins=denbins+0.15
bysort denbins: egen dendist=count(mdistance)

lpoly dendist mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 

lpoly dendist mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 

#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter dendist denbins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 900 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Number of households", size(medsmall) margin(small)) ylabel(0(300)900,labsize(medsmall) ) xtitle("Distance from Cutoff", size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value") rows(1)) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "figdenag.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 

*******************************************************************************
*	 FIGURE 2 DISCONTINUITY IN PROGRAM ACTIVITIES 6 MONTHS PRECEDING THE SURVEY
*******************************************************************************

egen bins = cut(mdistance), at(-6(0.3)6) 
replace bins=bins+0.15

bysort bins: egen mean_ag = mean (ag_vil) 
lpoly ag_vil mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 
 lpoly ag_vil mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 


#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter mean_ag bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 1 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Agriculture program coverage", size(medsmall) margin(small)) ylabel(0(0.2)1,labsize(medsmall)  format(%9.1f)) xtitle("Distance from Cutoff", size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(row (1) order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value" )) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "figag.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 


*******************************************************************************
*	 FIGURE 3 PROGRAM IMPACT ON PROPORTION OF HOUSEHOLD MEMBERS WITH MALARIA
*******************************************************************************

bysort bins: egen mean_malaria = mean (hhmalaria) 
lpoly hhmalaria mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 quietly gen yhigh_left=y_left+1.96*shat_left
 quietly gen ylow_left=y_left-1.96*shat_left
 
 lpoly hhmalaria mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 
 quietly gen yhigh_right=y_right+1.96*shat_right
 quietly gen ylow_right=y_right-1.96*shat_right

#delimit ;
twoway (scatter yhigh_left y_left ylow_left x_left if x_left<=0 & x_left>=-3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter yhigh_right y_right ylow_right x_right if x_right>0 & x_right<=3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter mean_malaria bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 0.6 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("HH malaria prevalence (last 6 months)", size(medsmall) margin(small)) ylabel(0(0.2)0.6,labsize(medsmall)  format(%9.1f)) xtitle("Distance from Cutoff", size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "95% C.I."  7 "0.3-km bin" 8 "Cutoff value" )) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "figmalaria.eps", as(eps) preview(off) replace
drop x_left y_left shat_left yhigh_left ylow_left x_right y_right shat_right yhigh_right ylow_right

*******************************************************************************
*	 FIGURE 4 EFFECTS ON MALARIA BY BANDWIDTHS
*******************************************************************************
* 1km to 4km, step=0.2km 
mat ESTIMATE=J(16,4,.)

qui forvalues H=10(2)40{
local h=`H'/10
rdrobust hhmalaria mdistance,  c(0) h(`h') vce(nncluster vid 17)
mat ESTIMATE[`H'/2-4,1]=-e(tau_cl)
mat ESTIMATE[`H'/2-4,2]=-e(tau_cl)+e(se_tau_cl)*1.96
mat ESTIMATE[`H'/2-4,3]=-e(tau_cl)-e(se_tau_cl)*1.96
mat ESTIMATE[`H'/2-4,4]=`h'
}

gen est_rd=.
gen est_upper=.
gen est_lower=.
gen est_h=.

qui forval i = 1/16 {
 replace est_rd = ESTIMATE[`i', 1] in `i'
 replace est_upper = ESTIMATE[`i', 2] in `i'
 replace est_lower = ESTIMATE[`i', 3] in `i'
 replace est_h = ESTIMATE[`i', 4] in `i'
}

#delimit ;
twoway (line est_rd est_h,clcolor(gs4)) 
(line est_upper est_h, lcolor(gs4) lpattern(dash))
(line est_lower est_h, lcolor(gs4) lpattern(dash)), 
ytitle("Effect on malaria", size(medsmall) margin(small)) ylabel(-0.2(0.05)0.05,labsize(medsmall)  format(%9.2f)) yline(0) xtitle("Bandwidth", size(medsmall) margin(small)) xlabel(1(1)4, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(1 "Estimated effect"  2 "95% confidence interval")rows(1)) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "figbandwidth.eps", as(eps) preview(off) replace

*******************************************************************************
*	 FIGURE 5A IMPACT OF PROGRAM ELIGIBILITY ON AG INCOME 
*******************************************************************************

bysort bins: egen mean_lincome_pc = mean (lag_income_pc) 
lpoly lag_income_pc mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 quietly gen yhigh_left=y_left+1.96*shat_left
 quietly gen ylow_left=y_left-1.96*shat_left
 
 lpoly lag_income_pc mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 
 quietly gen yhigh_right=y_right+1.96*shat_right
 quietly gen ylow_right=y_right-1.96*shat_right

#delimit ;
twoway (scatter yhigh_left y_left ylow_left x_left if x_left<=0 & x_left>=-3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter yhigh_right y_right ylow_right x_right if x_right>0 & x_right<=3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter mean_lincome_pc bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 9.8 0 12 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Log Agricultural Value Per Capita", size(medsmall) margin(small)) ylabel(10(0.5)12,labsize(medsmall)  format(%9.1f)) xtitle("Distance from Cutoff", size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "95% C.I."  7 "0.3-km bin" 8 "Cutoff value" )) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "figlincpc.eps", as(eps) preview(off) replace
drop x_left y_left shat_left yhigh_left ylow_left x_right y_right shat_right yhigh_right ylow_right

*******************************************************************************
*	 FIGURE 5B IMPACT OF PROGRAM ELIGIBILITY ON BEDNET OWNED PER CAPITA
*******************************************************************************

bysort bins: egen mean_netown = mean (netown) 
lpoly netown mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 quietly gen yhigh_left=y_left+1.96*shat_left
 quietly gen ylow_left=y_left-1.96*shat_left
 
 lpoly netown mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 
 quietly gen yhigh_right=y_right+1.96*shat_right
 quietly gen ylow_right=y_right-1.96*shat_right

#delimit ;
twoway (scatter yhigh_left y_left ylow_left x_left if x_left<=0 & x_left>=-3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter yhigh_right y_right ylow_right x_right if x_right>0 & x_right<=3, m(none none none) connect(l l l) lcolor(gray black gray) lpat(shortdash solid shortdash))
(scatter mean_netown bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0.2 0 0.63 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Number of Bednet Owned Per Capita", size(medsmall) margin(small)) ylabel(0.2(0.2)0.6,labsize(medsmall)  format(%9.1f)) xtitle("Distance from Cutoff", size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "95% C.I."  7 "0.3-km bin" 8 "Cutoff value" )) plotregion(lcolor(black) lwidth(thin));
#delimit cr
graph export "fignetpc.eps", as(eps) preview(off) replace
drop x_left y_left shat_left yhigh_left ylow_left x_right y_right shat_right yhigh_right ylow_right

*******************************************************************************
*	 FIGURE A2 DISCONTINUITY IN COVARIATES
*******************************************************************************

* Household head age
bysort bins: egen mean_headage = mean (hhheadage) 

lpoly hhheadage mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 
lpoly hhheadage mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 

#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter mean_headage bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 80 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Household head age", size(medsmall) margin(small)) ylabel(0(20)80,labsize(medsmall)  format(%9.0f)) xtitle(Distance from Cutoff, size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value") rows(1)) plotregion(lcolor(black) lwidth(thin)) ysize(3);
#delimit cr
graph export "figheadage.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 

* Household head literacy 
bysort bins: egen mean_headlit = mean (hhheadlit) 

lpoly hhheadlit mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 
lpoly hhheadlit mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 

#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter mean_headlit bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 1 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Household head literacy rate", size(medsmall) margin(small)) ylabel(0(0.2)1,labsize(medsmall)  format(%9.1f)) xtitle(Distance from Cutoff, size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value") rows(1)) plotregion(lcolor(black) lwidth(thin)) ysize(3);
#delimit cr
graph export "figheadlit.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 

* Presence of a committee member in the household
bysort bins: egen mean_member = mean (member) 

lpoly member mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 
lpoly member mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 

#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter mean_member bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 1 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Commettee member in the household", size(medsmall) margin(small)) ylabel(0(0.2)1,labsize(medsmall)  format(%9.1f)) xtitle(Distance from Cutoff, size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value") rows(1)) plotregion(lcolor(black) lwidth(thin)) ysize(3);
#delimit cr
graph export "figmember.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 

*******************************************************************************
*	 FIGURE A2d DISCONTINUITY IN HEALTH PROGRAM
*******************************************************************************

bysort bins: egen mean_health_vil = mean (health_vil) 

lpoly health_vil mdistance if mdistance<=0 & mdistance>=-3, degree(1) kernel(triangle) bwidth(2) /// 
 nograph generate(x_left y_left) se(shat_left) n(100) 
 
lpoly health_vil mdistance if mdistance>0 & mdistance<=3, degree(1) kernel(triangle) bwidth(2)  ///
nograph generate(x_right y_right)  se(shat_right)  n(100) 

#delimit ;
twoway (scatter y_left x_left if x_left<=0 & x_left>=-3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter  y_right  x_right if x_right>0 & x_right<=3, m(none) connect(l) lcolor(black) lpat(solid))
(scatter mean_health_vil bins if abs(mdistance)<=3, msize(medsmall) msymbol(circle) mfcolor(white) mlcolor(black) mlwidth(thin))
(scatteri 0 0 1 0, recast(line) lcolor(cranberry) lpattern(dash)), 
ytitle("Health program coverage", size(medsmall) margin(small)) ylabel(0(0.2)1,labsize(medsmall)  format(%9.1f)) xtitle(Distance from Cutoff, size(medsmall) margin(small)) xlabel(-3(1)3, labsize(medsmall))
graphregion(fcolor(white) lcolor(white)) legend(order(2 "Local polynomial fit" 3 "0.3-km bin" 4 "Cutoff value") rows(1)) plotregion(lcolor(black) lwidth(thin)) ysize(3);
#delimit cr
graph export "fighealth.eps", as(eps) preview(off) replace
drop x_left y_left shat_left x_right y_right shat_right 






********************************************************************************************************
* ADDITIONAL RESULTS IN APPENDIX B
********************************************************************************************************

* TABLE 3
* Without covariates
rdrobust hhmalaria mdistance if baldata==1,$default 
rdrobust hhmalaria mdistance if baldata==1,$small 
rdrobust hhmalaria mdistance if baldata==1,$large 
 
sum hhmalaria if abs(mdistance)<2 & baldata==1 //# of obs
sum hhmalaria if abs(mdistance)<1.5 & baldata==1
sum hhmalaria if abs(mdistance)<3 & baldata==1

sum hhmalaria if mdistance>0 & mdistance<2  &  baldata==1 //control mean
sum hhmalaria if mdistance>0 & mdistance<1.5 &  baldata==1
sum hhmalaria if mdistance>0 & mdistance<3 &  baldata==1


* TABLE 5 
* Income 
rdrobust lag_income_pc mdistance if baldata==1,$default
sum lag_income_pc if abs(mdistance)<2  & baldata==1
sum lag_income_pc if mdistance>0 & mdistance<2 & baldata==1

* Bednet ownership per capita
rdrobust netown mdistance if baldata==1, $default
sum netown if abs(mdistance)<2 & baldata==1 
sum netown if mdistance>0 & mdistance<2 & baldata==1 

















