*Do file for individual level results

use "$data/data/ready_ind.dta",clear
scalar n_main=_N
mata:data_main=st_data(.,.)
egen vid=group(c_code s_code p_code lc1_code)
label var vid "Village identifier"
bys vid: gen n_vil=_N
gen female=(male==0)	

gl control "hhheadage hhheadlit member distance hhr_gender imonth" 
*default bandwidth
gl default_a5 "c(0) h(2) vce(nncluster vid 13)"
gl default_a19 "c(0) h(2) vce(nncluster vid 39)"
gl default_a60 "c(0) h(2) vce(nncluster vid 35)"
gl default_a13 "c(0) h(2) vce(nncluster vid 21)"
gl default_m "c(0) h(2) vce(nncluster vid 43)"
gl default_f "c(0) h(2) vce(nncluster vid 46)"
gl default_p "c(0) h(2) vce(nncluster vid 3)"
gl default "c(0) h(2) vce(nncluster vid 40)"
*small bandwidth
gl small_a5 "c(0) h(1.5) vce(nncluster vid 13)"
gl small_a19 "c(0) h(1.5) vce(nncluster vid 39)"
gl small_a60 "c(0) h(1.5) vce(nncluster vid 35)"
gl small_m "c(0) h(1.5) vce(nncluster vid 43)"
gl small_f "c(0) h(1.5) vce(nncluster vid 46)"
gl small_p "c(0) h(1.5) vce(nncluster vid 3)"
*large bandwidth
gl large_a5 "c(0) h(3) vce(nncluster vid 13)"
gl large_a19 "c(0) h(3) vce(nncluster vid 39)"
gl large_a60 "c(0) h(3) vce(nncluster vid 35)"
gl large_m "c(0) h(3) vce(nncluster vid 43)"
gl large_f "c(0) h(3) vce(nncluster vid 46)"
gl large_p "c(0) h(3) vce(nncluster vid 3)"

gen baldata=1
foreach j of varlist $control {
	replace baldata=0 if `j'==.
	}

cap log close
log using "jdeindresults", replace

/*==========================================================================                                                                        
			
			This file produces all individual-level results

===========================================================================*/

*******************************************************************************
*	 TABLE 1 SUMMARY STATISTICS (FULL SAMPLE)
*******************************************************************************

sum malaria if age<=5
sum malaria if age>=6 & age<=19
sum malaria if age>=20 & age<=60
sum malaria if male==1
sum malaria if male==0
sum malaria if pregnant==1

*******************************************************************************
*	 TABLE 4 PROGRAM EFFECT ON INDIVIDIAL MALARIA INCIDENCE 
*******************************************************************************

* number of obs & control group mean: without covariates
sum malaria if abs(mdistance)<2 & age<=5
sum malaria if abs(mdistance)<2 & age>=6 & age<=19
sum malaria if abs(mdistance)<2 & age>=20 & age<=60
sum malaria if abs(mdistance)<2 & male==1
sum malaria if abs(mdistance)<2 & male==0
sum malaria if abs(mdistance)<2 & pregnant==1

sum malaria if mdistance<2 & mdistance>0 & age<=5
sum malaria if mdistance<2 & mdistance>0 & age>=6 & age<=19
sum malaria if mdistance<2 & mdistance>0 & age>=20 & age<=60
sum malaria if mdistance<2 & mdistance>0 & male==1
sum malaria if mdistance<2 & mdistance>0 & male==0
sum malaria if mdistance<2 & mdistance>0 & pregnant==1

* program impact on malaria: without coveriates
rdrobust malaria mdistance if age<=5,$default_a5
scalar one_rd=e(tau_cl)
scalar one_rdse=e(se_tau_cl)
rdrobust malaria mdistance if age>=6 & age<=19,$default_a19
scalar two_rd=e(tau_cl)
scalar two_rdse=e(se_tau_cl)
rdrobust malaria mdistance if age>=20 & age<=60,$default_a60
scalar three_rd=e(tau_cl)
scalar three_rdse=e(se_tau_cl)

rdrobust malaria mdistance if male==1,$default_m
scalar four_rd=e(tau_cl)
scalar four_rdse=e(se_tau_cl)
rdrobust malaria mdistance if male==0,$default_f
scalar five_rd=e(tau_cl)
scalar five_rdse=e(se_tau_cl)

rdrobust malaria mdistance if pregnant==1,$default_p

* t-statistic b/w age groups: without covariates
scalar tstat=(one_rd-three_rd)/sqrt(one_rdse^2+three_rdse^2)
display tstat //<5 vs 20-60, malaria
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(two_rd-three_rd)/sqrt(two_rdse^2+three_rdse^2)
display tstat //6-19 vs 20-60, malaria
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(one_rd-two_rd)/sqrt(one_rdse^2+two_rdse^2)
display tstat //6-19 vs 0-5, malaria
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(four_rd-five_rd)/sqrt(four_rdse^2+five_rdse^2)
display tstat //male vs female, malaria
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 


scalar drop _all 

* number of obs & control group mean: with covariates
sum malaria if abs(mdistance)<2 & age<=5 & baldata==1
sum malaria if abs(mdistance)<2 & age>=6 & age<=19 & baldata==1
sum malaria if abs(mdistance)<2 & age>=20 & age<=60 & baldata==1
sum malaria if abs(mdistance)<2 & male==1 & baldata==1
sum malaria if abs(mdistance)<2 & male==0 & baldata==1
sum malaria if abs(mdistance)<2 & pregnant==1 & baldata==1

sum malaria if mdistance<2 & mdistance>0 & age<=5 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & age>=6 & age<=19 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & age>=20 & age<=60 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & male==1 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & male==0 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & baldata==1

* program impact on malaria: with coveriates
rdrobust malaria mdistance if age<=5, covs($control) $default_a5
rdrobust malaria mdistance if age>=6 & age<=19, covs($control) $default_a19
rdrobust malaria mdistance if age>=20 & age<=60, covs($control) $default_a60
rdrobust malaria mdistance if male==1, covs($control) $default_m
rdrobust malaria mdistance if male==0, covs($control) $default_f
rdrobust malaria mdistance if pregnant==1, covs($control) $default_p


*******************************************************************************
*	 TABLE 6 PROGRAM EFFECT ON INDIVIDIAL BEDNET USAGE
*******************************************************************************

* number of obs & control group mean: without covariates
sum net if abs(mdistance)<2 & age<=5
sum net if abs(mdistance)<2 & age>=6 & age<=19
sum net if abs(mdistance)<2 & age>=20 & age<=60
sum net if abs(mdistance)<2 & male==1
sum net if abs(mdistance)<2 & male==0
sum net if abs(mdistance)<2 & pregnant==1

sum net if mdistance<2 & mdistance>0 & age<=5
sum net if mdistance<2 & mdistance>0 & age>=6 & age<=19
sum net if mdistance<2 & mdistance>0 & age>=20 & age<=60
sum net if mdistance<2 & mdistance>0 & male==1
sum net if mdistance<2 & mdistance>0 & male==0
sum net if mdistance<2 & mdistance>0 & pregnant==1

* program impact on net usage: without coveriates
rdrobust net mdistance if age<=5,$default_a5
scalar one_rd1=e(tau_cl)
scalar one_rdse1=e(se_tau_cl)
rdrobust net mdistance if age>=6 & age<=19,$default_a19
scalar two_rd1=e(tau_cl)
scalar two_rdse1=e(se_tau_cl)
rdrobust net mdistance if age>=20 & age<=60,$default_a60
scalar three_rd1=e(tau_cl)
scalar three_rdse1=e(se_tau_cl)

rdrobust net mdistance if male==1,$default_m
scalar four_rd=e(tau_cl)
scalar four_rdse=e(se_tau_cl)
rdrobust net mdistance if male==0,$default_f
scalar five_rd=e(tau_cl)
scalar five_rdse=e(se_tau_cl)

rdrobust net mdistance if pregnant==1,$default_p

* t-statistic b/w age groups: without covariates
scalar tstat=(one_rd1-three_rd1)/sqrt(one_rdse1^2+three_rdse1^2)
display tstat //<5 vs 20-60, net
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(two_rd1-three_rd1)/sqrt(two_rdse1^2+three_rdse1^2)
display tstat //6-19 vs 20-60, net
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(one_rd1-two_rd1)/sqrt(one_rdse1^2+two_rdse1^2)
display tstat //6-19 vs 0-5, net
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 

scalar tstat=(four_rd-five_rd)/sqrt(four_rdse^2+five_rdse^2)
display tstat //male vs female, net
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 
scalar drop _all 

* number of obs & control group mean: with covariates
sum net if abs(mdistance)<2 & age<=5 & baldata==1
sum net if abs(mdistance)<2 & age>=6 & age<=19 & baldata==1
sum net if abs(mdistance)<2 & age>=20 & age<=60 & baldata==1
sum net if abs(mdistance)<2 & male==1 & baldata==1
sum net if abs(mdistance)<2 & male==0 & baldata==1
sum net if abs(mdistance)<2 & pregnant==1 & baldata==1

sum net if mdistance<2 & mdistance>0 & age<=5 & baldata==1
sum net if mdistance<2 & mdistance>0 & age>=6 & age<=19 & baldata==1
sum net if mdistance<2 & mdistance>0 & age>=20 & age<=60 & baldata==1
sum net if mdistance<2 & mdistance>0 & male==1 & baldata==1
sum net if mdistance<2 & mdistance>0 & male==0 & baldata==1
sum net if mdistance<2 & mdistance>0 & pregnant==1 & baldata==1

* program impact on malaria: with covariates
rdrobust net mdistance if age<=5, covs($control) $default_a5
rdrobust net mdistance if age>=6 & age<=19, covs($control) $default_a19
rdrobust net mdistance if age>=20 & age<=60, covs($control) $default_a60
rdrobust net mdistance if male==1, covs($control) $default_m
rdrobust net mdistance if male==0, covs($control) $default_f
rdrobust net mdistance if pregnant==1, covs($control) $default_p

*******************************************************************************
*	 TABLE 7 MALARIA INTRA-HOUSEHOLD SPILLOVER ON PREGNANT WOMEN
*******************************************************************************

* Households without under 5 children
rdrobust malaria mdistance if pregnant==1 & num5==0, $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5==0
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5==0
rdrobust malaria mdistance if pregnant==1  & num5==0, covs($control) $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5==0 &  baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5==0 &  baldata==1

* Households with under 5 children
rdrobust malaria mdistance if pregnant==1 & num5>=1, $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5>=1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5>=1
rdrobust malaria mdistance if pregnant==1  & num5>=1, covs($control) $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5>=1 &  baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5>=1 &  baldata==1

*******************************************************************************
*	 TABLE 9 PROBABILITY OF BEING SICK
*******************************************************************************
* Additional result: likelihood of being sick 
rdrobust illness mdistance if age<=5,$default_a5
count if abs(mdistance)<=2 & illness!=. & age<=5
sum illness if mdistance<2 & mdistance>0 & illness!=. & age<=5
rdrobust illness mdistance if age>=6 & age<=19,$default_a19
count if abs(mdistance)<=2 & illness!=. & age>=6 & age<=19
sum illness if mdistance<2 & mdistance>0 & illness!=. & age>=6 & age<=19
rdrobust illness mdistance if age>=20 & age<=60,$default_a60
count if abs(mdistance)<=2 & illness!=. & age>=20 & age<=60
sum illness if mdistance<2 & mdistance>0 & illness!=. & age>=20 & age<=60
* Rain season: March-May & Sept-Dec; survey mo with refering period not overlapping with rain season:July-Sept
//not overlap
sum illness if abs(mdistance)<2 & (imonth1==1 | imonth2==1 | imonth3==1) & age<=5
sum illness if mdistance<2 & mdistance>0 & (imonth1==1 | imonth2==1 | imonth3==1) & age<=5
rdrobust illness mdistance if (imonth1==1 | imonth2==1 | imonth3==1) & age<=5, $default_a5

sum illness if abs(mdistance)<2 & (imonth1==1 | imonth2==1 | imonth3==1) & age>=6 & age<=19
sum illness if mdistance<2 & mdistance>0 & (imonth1==1 | imonth2==1 | imonth3==1) & age>=6 & age<=19
rdrobust illness mdistance if (imonth1==1 | imonth2==1 | imonth3==1) & age>=6 & age<=19, $default_a19

sum illness if abs(mdistance)<2 & (imonth1==1 | imonth2==1 | imonth3==1) & age>=20 & age<=60
sum illness if mdistance<2 & mdistance>0 & (imonth1==1 | imonth2==1 | imonth3==1) & age>=20 & age<=60
rdrobust illness mdistance if (imonth1==1 | imonth2==1 | imonth3==1) & age>=20 & age<=60, $default_a60

//overlap

sum illness if abs(mdistance)<2 & (imonth4==1 | imonth5==1 | imonth6==1) & age<=5
sum illness if mdistance<2 & mdistance>0 & (imonth4==1 | imonth5==1 | imonth6==1) & age<=5
rdrobust illness mdistance if (imonth4==1 | imonth5==1 | imonth6==1) & age<=5, $default_a5

sum illness if abs(mdistance)<2 & (imonth4==1 | imonth5==1 | imonth6==1) & age>=6 & age<=19
sum illness if mdistance<2 & mdistance>0 & (imonth4==1 | imonth5==1 | imonth6==1) & age>=6 & age<=19
rdrobust illness mdistance if (imonth4==1 | imonth5==1 | imonth6==1) & age>=6 & age<=19, $default_a19

sum illness if abs(mdistance)<2 & (imonth4==1 | imonth5==1 | imonth6==1) & age>=20 & age<=60
sum illness if mdistance<2 & mdistance>0 & (imonth4==1 | imonth5==1 | imonth6==1) & age>=20 & age<=60
rdrobust illness mdistance if (imonth4==1 | imonth5==1 | imonth6==1) & age>=20 & age<=60, $default_a60

*******************************************************************************
*	 TABLE 10 OTHER RELATED OUTCOMES
*******************************************************************************

* School attendance for children aged 7-13
rdrobust sch_attend mdistance if age>=7 & age<=13, $default_a13
sum sch_attend if abs(mdistance)<2 & age>=7 & age<=13
sum sch_attend if mdistance<2 & mdistance>0  & age>=7 & age<=13

* Overage for children aged 7-13
rdrobust over_age mdistance if age>=7 & age<=13, $default_a13
sum over_age if abs(mdistance)<2 & age>=7 & age<=13
sum over_age if mdistance<2 & mdistance>0 & age>=7 & age<=13

*******************************************************************************
*	 TABLE A2 EFFECTS ON MALARIA: PARAMETRIC ESTIMATES
*******************************************************************************

gen cutoff=(mdistance<=0)
gen x=mdistance
gen x2=x^2
gen xint=x*cutoff
gen x2int=x2*cutoff

reg malaria cutoff x xint x2 x2int if age<=5,cluster(vid) 
reg malaria cutoff x xint x2 x2int if age>=6 & age<=19,cluster(vid) 
reg malaria cutoff x xint x2 x2int if age>=20 & age<=60,cluster(vid) 
reg malaria cutoff x xint x2 x2int if male==1,cluster(vid) 
reg malaria cutoff x xint x2 x2int if male==0,cluster(vid) 
reg malaria cutoff x xint x2 x2int if pregnant==1,cluster(vid) 

reg malaria cutoff x xint x2 x2int $control if age<=5,cluster(vid) 
reg malaria cutoff x xint x2 x2int $control if age>=6 & age<=19,cluster(vid) 
reg malaria cutoff x xint x2 x2int $control if age>=20 & age<=60,cluster(vid) 
reg malaria cutoff x xint x2 x2int $control if male==1,cluster(vid) 
reg malaria cutoff x xint x2 x2int $control if male==0,cluster(vid) 
reg malaria cutoff x xint x2 x2int $control if pregnant==1,cluster(vid) 

sum malaria if mdistance>0 & age<=5 
sum malaria if mdistance>0 & age>=6 & age<=19
sum malaria if mdistance>0 & age>=20 & age<=60
sum malaria if mdistance>0 & male==1
sum malaria if mdistance>0 & male==0
sum malaria if mdistance>0 & pregnant==1

sum malaria if mdistance>0 & age<=5 & baldata==1 
sum malaria if mdistance>0 & age>=6 & age<=19 & baldata==1 
sum malaria if mdistance>0 & age>=20 & age<=60 & baldata==1 
sum malaria if mdistance>0 & male==1 & baldata==1 
sum malaria if mdistance>0 & male==0 & baldata==1 
sum malaria if mdistance>0 & pregnant==1 & baldata==1 

*******************************************************************************
*	 TABLE A3 PROGRAM EFFECT ON INDIVIDIAL MALARIA INCIDENCE: ALTERNATIVE BANDWIDTH
*******************************************************************************

sum malaria if abs(mdistance)<1.5 & age<=5
sum malaria if abs(mdistance)<1.5 & age>=6 & age<=19
sum malaria if abs(mdistance)<1.5 & age>=20 & age<=60
sum malaria if abs(mdistance)<1.5 & male==1
sum malaria if abs(mdistance)<1.5 & male==0
sum malaria if abs(mdistance)<1.5 & pregnant==1

sum malaria if abs(mdistance)<3 & age<=5
sum malaria if abs(mdistance)<3 & age>=6 & age<=19
sum malaria if abs(mdistance)<3 & age>=20 & age<=60
sum malaria if abs(mdistance)<3 & male==1
sum malaria if abs(mdistance)<3 & male==0
sum malaria if abs(mdistance)<3 & pregnant==1

rdrobust malaria mdistance if age<=5, $small_a5
rdrobust malaria mdistance if age<=5, $large_a5

rdrobust malaria mdistance if age>=6 & age<=19, $small_a19
rdrobust malaria mdistance if age>=6 & age<=19, $large_a19

rdrobust malaria mdistance if age>=20 & age<=60, $small_a60
rdrobust malaria mdistance if age>=20 & age<=60, $large_a60

rdrobust malaria mdistance if male==1, $small_m
rdrobust malaria mdistance if male==1, $large_m

rdrobust malaria mdistance if male==0, $small_f
rdrobust malaria mdistance if male==0, $large_f

rdrobust malaria mdistance if pregnant==1, $small_p
rdrobust malaria mdistance if pregnant==1, $large_p

sum malaria if mdistance>0 & mdistance<1.5 & age<=5 
sum malaria if mdistance>0 & mdistance<1.5 & age>=6 & age<=19 
sum malaria if mdistance>0 & mdistance<1.5 & age>=20 & age<=60 
sum malaria if mdistance>0 & mdistance<1.5 & male==1 
sum malaria if mdistance>0 & mdistance<1.5 & male==0 
sum malaria if mdistance>0 & mdistance<1.5 & pregnant==1 

sum malaria if mdistance>0 & mdistance<3 & age<=5 
sum malaria if mdistance>0 & mdistance<3 & age>=6 & age<=19 
sum malaria if mdistance>0 & mdistance<3 & age>=20 & age<=60 
sum malaria if mdistance>0 & mdistance<3 & male==1 
sum malaria if mdistance>0 & mdistance<3 & male==0 
sum malaria if mdistance>0 & mdistance<3 & pregnant==1 


*******************************************************************************
*	 OTHER RESULTS REPORTED IN THE TEXT
*******************************************************************************

* ANC visit during pregnancy
rdrobust anc mdistance, $default_p

* R2 point 8: Likelihood of health center visit conditional on being sick 
rdrobust visit mdistance, $default


*******************************************************************************
*	 ADDITIONAL RESULTS IN APPENDIX
*******************************************************************************
* Difference in age effects differ by gender
*age 0-5
rdrobust malaria mdistance if age<=5 & male==1, $default_a5
scalar rd1=e(tau_cl)
scalar rdse1=e(se_tau_cl)
rdrobust malaria mdistance if age<=5 & male==0, $default_a5
scalar rd2=e(tau_cl)
scalar rdse2=e(se_tau_cl)
scalar tstat=(rd1-rd2)/sqrt(rdse1^2+rdse2^2)
display tstat
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 
scalar drop _all 
sum malaria if mdistance<2 & mdistance>0 & male==1 & age<=5
sum malaria if mdistance<2 & mdistance>0 & male==0 & age<=5

*age 6-19
rdrobust malaria mdistance if age>=6 & age<=19 & male==1, $default_a19
scalar rd1=e(tau_cl)
scalar rdse1=e(se_tau_cl)
rdrobust malaria mdistance if age>=6 & age<=19 & male==0, $default_a19
scalar rd2=e(tau_cl)
scalar rdse2=e(se_tau_cl)
scalar tstat=(rd1-rd2)/sqrt(rdse1^2+rdse2^2)
display tstat
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 
scalar drop _all 
sum malaria if mdistance<2 & mdistance>0 & male==1 & age>=6 & age<=19
sum malaria if mdistance<2 & mdistance>0 & male==0 & age>=6 & age<=19

*age 20-60
rdrobust malaria mdistance if age>=20 & age<=60 & male==1, $default_a60
scalar rd1=e(tau_cl)
scalar rdse1=e(se_tau_cl)
rdrobust malaria mdistance if age>=20 & age<=60 & male==0, $default_a60
scalar rd2=e(tau_cl)
scalar rdse2=e(se_tau_cl)
scalar tstat=(rd1-rd2)/sqrt(rdse1^2+rdse2^2)
display tstat
scalar pvalue = 2*(1-normal(abs(tstat)))
scalar list pvalue 
scalar drop _all 
sum malaria if mdistance<2 & mdistance>0 & male==1 & age>=20 & age<=60 
sum malaria if mdistance<2 & mdistance>0 & male==0 & age>=20 & age<=60 



********************************************************************************************************
* ADDITIONAL RESULTS IN APPENDIX B
********************************************************************************************************
*Table 4 - malaria
*without covariates
rdrobust malaria mdistance if age<=5 & baldata==1, $default_a5
rdrobust malaria mdistance if age>=6 & age<=19 & baldata==1, $default_a19
rdrobust malaria mdistance if age>=20 & age<=60 & baldata==1, $default_a60
rdrobust malaria mdistance if male==1 & baldata==1, $default_m
rdrobust malaria mdistance if male==0 & baldata==1, $default_f
rdrobust malaria mdistance if pregnant==1 & baldata==1,  $default_p


sum malaria if abs(mdistance)<2 & age<=5 & baldata==1
sum malaria if abs(mdistance)<2 & age>=6 & age<=19 & baldata==1
sum malaria if abs(mdistance)<2 & age>=20 & age<=60 & baldata==1
sum malaria if abs(mdistance)<2 & male==1 & baldata==1
sum malaria if abs(mdistance)<2 & male==0 & baldata==1
sum malaria if abs(mdistance)<2 & pregnant==1 & baldata==1

sum malaria if mdistance<2 & mdistance>0 & age<=5 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & age>=6 & age<=19 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & age>=20 & age<=60 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & male==1 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & male==0 & baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & baldata==1


*Table 6 - betnets
*without covariates
rdrobust net mdistance if age<=5 & baldata==1, $default_a5
rdrobust net mdistance if age>=6 & age<=19 & baldata==1, $default_a19
rdrobust net mdistance if age>=20 & age<=60 & baldata==1, $default_a60
rdrobust net mdistance if male==1 & baldata==1, $default_m
rdrobust net mdistance if male==0 & baldata==1, $default_f
rdrobust net mdistance if pregnant==1 & baldata==1,  $default_p

sum net if abs(mdistance)<2 & age<=5 & baldata==1
sum net if abs(mdistance)<2 & age>=6 & age<=19 & baldata==1
sum net if abs(mdistance)<2 & age>=20 & age<=60 & baldata==1
sum net if abs(mdistance)<2 & male==1 & baldata==1
sum net if abs(mdistance)<2 & male==0 & baldata==1
sum net if abs(mdistance)<2 & pregnant==1 & baldata==1

sum net if mdistance<2 & mdistance>0 & age<=5 & baldata==1
sum net if mdistance<2 & mdistance>0 & age>=6 & age<=19 & baldata==1
sum net if mdistance<2 & mdistance>0 & age>=20 & age<=60 & baldata==1
sum net if mdistance<2 & mdistance>0 & male==1 & baldata==1
sum net if mdistance<2 & mdistance>0 & male==0 & baldata==1
sum net if mdistance<2 & mdistance>0 & pregnant==1 & baldata==1

*Table 7
* Households without/with under 5 children
rdrobust malaria mdistance if pregnant==1 & num5==0 & baldata==1, $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5==0 &  baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5==0 &  baldata==1
rdrobust malaria mdistance if pregnant==1 & num5>=1 & baldata==1, $default_p
sum malaria if abs(mdistance)<2 & pregnant==1 & num5>=1 &  baldata==1
sum malaria if mdistance<2 & mdistance>0 & pregnant==1 & num5>=1 &  baldata==1
